==> jc-1.4.0.tar.gz: javax/swing/tree/DefaultTreeCellEditor__24EditorContainer.h <==
// public class javax.swing.tree.DefaultTreeCellEditor$EditorContainer

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class faccb77356789885 javax_swing_tree_DefaultTreeCellEditor__24EditorContainer

// header file dependencies
// @dep_header java_awt_Container

#include "java/awt/Container.h"

#ifndef _JC_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer_H_
#define _JC_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer_H_

// Forward structure declarations
struct _jc_java_awt_Dimension$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_tree_DefaultTreeCellEditor$object;

// Typedefs
typedef struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$sub_refs	_jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$sub_refs;
typedef struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$sub_nonrefs	_jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$sub_nonrefs;
typedef struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$refs	_jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$refs;
typedef struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$nonrefs	_jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$nonrefs;
typedef struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$object	_jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$object;

typedef const struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$vmethods	_jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$vmethods;
typedef const struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$vtable	_jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$vtable;
typedef const struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$vtype	_jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$vtype;

// Constructors
extern void _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$method$_init$393eacdfd15b3b0e(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$object *, struct _jc_javax_swing_tree_DefaultTreeCellEditor$object *);

// Virtual methods
extern void _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$method$EditorContainer$d32fd8678f3294e3(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$object *);
extern void _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$method$doLayout$0be726129a3039be(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$object *);
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$method$getPreferredSize$4730bc91c97b24d9(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$object *);
extern void _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$method$paint$76f038a09cf0c480(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$object *, struct _jc_java_awt_Graphics$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$method_info$EditorContainer$d32fd8678f3294e3;
extern _jc_method _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$method_info$doLayout$0be726129a3039be;
extern _jc_method _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$method_info$getPreferredSize$4730bc91c97b24d9;
extern _jc_method _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$method_info$paint$76f038a09cf0c480;

// Virtual methods structure
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$vmethods {
	void	(*EditorContainer$d32fd8678f3294e3)(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$object *);
	void	(*doLayout$0be726129a3039be)(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$object *);
	struct _jc_java_awt_Dimension$object	*(*getPreferredSize$4730bc91c97b24d9)(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$object *);
	void	(*paint$76f038a09cf0c480)(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$object *, struct _jc_java_awt_Graphics$object *);
};

// Vtable
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$vmethods	javax_swing_tree_DefaultTreeCellEditor__24EditorContainer;
};

// Vtype
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$vtype {
	_jc_type			type;
	_jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$sub_refs {
	struct _jc_javax_swing_tree_DefaultTreeCellEditor$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$refs {
    _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$sub_refs	javax_swing_tree_DefaultTreeCellEditor__24EditorContainer;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$sub_nonrefs	javax_swing_tree_DefaultTreeCellEditor__24EditorContainer;
};

// Object instance structure
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$object {
	_jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$vtype	*vtype;
	_jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$vtype _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_tree_DefaultTreeCellEditor__24EditorContainer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$class_object;

#endif	/* _JC_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer_H_ */

==> jc-1.4.5.tar.gz: javax/swing/tree/DefaultTreeCellEditor__24EditorContainer.h <==
// public class javax.swing.tree.DefaultTreeCellEditor$EditorContainer

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class faccb77356789885 javax_swing_tree_DefaultTreeCellEditor__24EditorContainer

// header file dependencies
// @dep_header java_awt_Container

#include "java/awt/Container.h"

#ifndef _JC_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer_H_
#define _JC_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer_H_

// Forward structure declarations
struct _jc_java_awt_Dimension$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_tree_DefaultTreeCellEditor$object;

// Typedefs
typedef struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$sub_refs	_jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$sub_refs;
typedef struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$sub_nonrefs	_jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$sub_nonrefs;
typedef struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$refs	_jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$refs;
typedef struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$nonrefs	_jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$nonrefs;
typedef struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$object	_jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$object;

typedef const struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$vmethods	_jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$vmethods;
typedef const struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$vtable	_jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$vtable;
typedef const struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$vtype	_jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$vtype;

// Constructors
extern void _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$method$_init$393eacdfd15b3b0e(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$object *, struct _jc_javax_swing_tree_DefaultTreeCellEditor$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$method$EditorContainer$d32fd8678f3294e3(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$method$doLayout$0be726129a3039be(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$method$getPreferredSize$4730bc91c97b24d9(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$method$paint$76f038a09cf0c480(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$method_info$EditorContainer$d32fd8678f3294e3;
extern _jc_method _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$method_info$doLayout$0be726129a3039be;
extern _jc_method _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$method_info$getPreferredSize$4730bc91c97b24d9;
extern _jc_method _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$method_info$paint$76f038a09cf0c480;

// Virtual methods structure
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$vmethods {
	void	(*EditorContainer$d32fd8678f3294e3)(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$object *) _JC_JCNI_ATTR;
	void	(*doLayout$0be726129a3039be)(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*getPreferredSize$4730bc91c97b24d9)(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$object *) _JC_JCNI_ATTR;
	void	(*paint$76f038a09cf0c480)(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$vmethods	javax_swing_tree_DefaultTreeCellEditor__24EditorContainer;
};

// Vtype
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$vtype {
	_jc_type			type;
	_jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$sub_refs {
	struct _jc_javax_swing_tree_DefaultTreeCellEditor$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$refs {
    _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$sub_refs	javax_swing_tree_DefaultTreeCellEditor__24EditorContainer;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$sub_nonrefs	javax_swing_tree_DefaultTreeCellEditor__24EditorContainer;
};

// Object instance structure
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$object {
	_jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$vtype	*vtype;
	_jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$vtype _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_tree_DefaultTreeCellEditor__24EditorContainer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer$class_object;

#endif	/* _JC_javax_swing_tree_DefaultTreeCellEditor__24EditorContainer_H_ */
